@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bozo/cronbnodeops.c,v 1.4 2001/07/12 19:58:26 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bozo/cronbnodeops.c,v 1.5.2.1 2001/09/19 22:36:19 shadow Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -120,6 +120,7 @@ register struct cronbnode *abnode; {
 	if (temp < 1) temp = 1;	/* temp is when to start dude */
 	bnode_SetTimeout(abnode, temp);
     }
+    return 0;
 }
 
 static int cron_restartp (abnode)
@@ -151,7 +152,7 @@ char *acommand; {
     }
 
     te = (struct cronbnode *) malloc(sizeof(struct cronbnode));
-    bzero(te, sizeof(struct cronbnode));
+    memset(te, 0, sizeof(struct cronbnode));
     code = ktime_ParsePeriodic(awhen, &te->whenToRun);
     if (code < 0) {
 	free(te);
