@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bucoord/main.c,v 1.4 2001/07/12 19:58:27 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bucoord/main.c,v 1.6.2.1 2001/09/19 22:40:24 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -108,18 +108,18 @@ osi_audit() {return 0;}
  */
 void InitErrTabs()
 {
-    initialize_acfg_error_table();
-    initialize_ka_error_table();
-    initialize_rxk_error_table();
-    initialize_cmd_error_table();
-    initialize_vl_error_table();
-    initialize_butm_error_table();
-    initialize_vols_error_table();
-    initialize_butc_error_table();
-    initialize_butx_error_table();
-    initialize_budb_error_table();
-    initialize_bucd_error_table();
-    initialize_ktc_error_table();
+    initialize_ACFG_error_table();
+    initialize_KA_error_table();
+    initialize_RXK_error_table();
+    initialize_CMD_error_table();
+    initialize_VL_error_table();
+    initialize_BUTM_error_table();
+    initialize_VOLS_error_table();
+    initialize_BUTC_error_table();
+    initialize_BUTX_error_table();
+    initialize_BUDB_error_table();
+    initialize_BUCD_error_table();
+    initialize_KTC_error_table();
 }
 
 /* 
@@ -195,7 +195,7 @@ bc_InitTextConfig()
 
     for ( i = 0; i < TB_NUM; i++ )
     {
-	bzero(ctPtr, sizeof(*ctPtr));
+	memset(ctPtr, 0, sizeof(*ctPtr));
 	ctPtr->textType = i;
 	ctPtr->textVersion = -1;
 	ctPtr++;
@@ -232,7 +232,7 @@ static int backupInit()
     extern statusWatcher();
 
     /* Initialization */
-    initialize_cmd_error_table();
+    initialize_CMD_error_table();
 
     /* don't run more than once */
     if (initd) 
@@ -688,13 +688,17 @@ main(argc, argv)
     /* Iterate on command lines, interpreting user commands (interactive mode) */
     while(1) 
     {
+	int ret;
+
 	printf("backup> ");
 	fflush(stdout);
 
 	
-	while (LWP_GetLine(lineBuffer, sizeof(lineBuffer)) == 0)
+	while ((ret = LWP_GetLine(lineBuffer, sizeof(lineBuffer))) == 0)
 	  printf("%s: Command line too long\n", whoami); /* line too long */
-	
+
+	if (ret == -1) return 0; /* Got EOF */
+
 	if ( !LineIsBlank(lineBuffer) ) 
 	{
 	    code = cmd_ParseLine(lineBuffer, targv, &targc, MAXV);
