@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/cmd/cmd.c,v 1.6 2001/07/12 19:58:29 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/cmd/cmd.c,v 1.6.4.1 2001/09/19 22:36:20 shadow Exp $");
 
 #include <sys/types.h>
 #include <ctype.h>
@@ -68,7 +68,7 @@ static int FindType(as, aname)
 register struct cmd_syndesc *as;
 register char *aname; {
     register int i;
-    int cmdlen;
+    size_t cmdlen;
     int ambig;
     int best;
 
@@ -95,7 +95,7 @@ int *aambig;
 char *aname; {
     register struct cmd_syndesc *ts;
     struct cmd_syndesc *best;
-    int cmdLen;
+    size_t cmdLen;
     int ambig;
 
     cmdLen = strlen(aname);
@@ -199,7 +199,7 @@ void PrintFlagHelp(as)
 register struct cmd_syndesc *as; {
     register int i;
     register struct cmd_parmdesc *tp;
-    int flag_width;
+    size_t flag_width;
     char *flag_prefix;
 
     /* find flag name length */
