@@ -7,17 +7,19 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
 /*******************************************************************\
 * 								    *
 * 	Information Technology Center				    *
 * 	Carnegie-Mellon University				    *
 * 								    *
 \*******************************************************************/
+#include <afsconfig.h>
 #include <afs/param.h>
 
-#if defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV) || defined(AFS_DJGPP_ENV)
+RCSID("$Header: /cvs/openafs/src/lwp/preempt.c,v 1.10.2.1 2001/09/19 22:25:25 shadow Exp $");
+
+
+#if defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_DJGPP_ENV)
 int PRE_Block = 0;
 #else
 #include <sys/time.h>
@@ -65,7 +67,7 @@ int PRE_InitPreempt(slice)
 	itv.it_interval = itv.it_value = *slice;
 	}
 
-    bzero((char *)&action, sizeof(action));
+    memset((char *)&action, 0, sizeof(action));
     action.sa_sigaction = AlarmHandler;
     action.sa_flags = SA_SIGINFO;
 
@@ -85,7 +87,7 @@ int PRE_EndPreempt()
     
     itv.it_value.tv_sec = itv.it_value.tv_usec = 0;
 
-    bzero((char *)&action, sizeof(action));
+    memset((char *)&action, 0, sizeof(action));
     action.sa_handler = SIG_DFL;
 
     if ((setitimer(ITIMER_REAL, &itv, (struct itimerval *) 0) == -1) ||
