@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ubik/vote.c,v 1.7.2.2 2001/09/20 03:58:52 shadow Exp $");
+
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -339,7 +343,7 @@ SVOTE_XSDebug(rxcall, awhich, aparm, isclone)
 	    	aparm->altAddr[i] = ntohl(ts->addr[i+1]);
 	    aparm->lastVoteTime = ts->lastVoteTime;
 	    aparm->lastBeaconSent = ts->lastBeaconSent;
-	    bcopy(&ts->version, &aparm->remoteVersion, sizeof(struct ubik_version));
+	    memcpy(&aparm->remoteVersion, &ts->version, sizeof(struct ubik_version));
 	    aparm->lastVote = ts->lastVote;
 	    aparm->up = ts->up;
 	    aparm->beaconSinceDown = ts->beaconSinceDown;
@@ -402,8 +406,8 @@ SVOTE_Debug(rxcall, aparm)
 	(urecovery_state & UBIK_RECHAVEDB  ) ) {
        aparm->recoveryState |= UBIK_RECLABELDB;
     }
-    bcopy(&ubik_dbVersion, &aparm->syncVersion, sizeof(struct ubik_version));
-    bcopy(&ubik_dbTid, &aparm->syncTid, sizeof(struct ubik_tid));
+    memcpy(&aparm->syncVersion, &ubik_dbVersion, sizeof(struct ubik_version));
+    memcpy(&aparm->syncTid, &ubik_dbTid, sizeof(struct ubik_tid));
     aparm->activeWrite = (ubik_dbase->flags & DBWRITING);
     aparm->tidCounter = ubik_dbase->tidCounter;
     
@@ -426,14 +430,14 @@ SVOTE_SDebugOld(rxcall, awhich, aparm)
     afs_int32 awhich;
     register struct ubik_sdebug_old *aparm; {
     register struct ubik_server *ts;
-    register int i;
+
     for(ts=ubik_servers; ts; ts=ts->next) {
 	if (awhich-- == 0) {
 	    /* we're done */
 	    aparm->addr = ntohl(ts->addr[0]); /* primary interface */
 	    aparm->lastVoteTime = ts->lastVoteTime;
 	    aparm->lastBeaconSent = ts->lastBeaconSent;
-	    bcopy(&ts->version, &aparm->remoteVersion, sizeof(struct ubik_version));
+	    memcpy(&aparm->remoteVersion, &ts->version, sizeof(struct ubik_version));
 	    aparm->lastVote = ts->lastVote;
 	    aparm->up = ts->up;
 	    aparm->beaconSinceDown = ts->beaconSinceDown;
@@ -449,7 +453,7 @@ SVOTE_SDebugOld(rxcall, awhich, aparm)
 SVOTE_DebugOld(rxcall, aparm)
     struct rx_call *rxcall;
     register struct ubik_debug_old *aparm; {
-    int  i;
+
     /* fill in the basic debug structure.  Note the the RPC protocol transfers,
      * integers in host order. */
     
@@ -480,8 +484,8 @@ SVOTE_DebugOld(rxcall, aparm)
 	(urecovery_state & UBIK_RECHAVEDB  ) ) {
        aparm->recoveryState |= UBIK_RECLABELDB;
     }
-    bcopy(&ubik_dbVersion, &aparm->syncVersion, sizeof(struct ubik_version));
-    bcopy(&ubik_dbTid, &aparm->syncTid, sizeof(struct ubik_tid));
+    memcpy(&aparm->syncVersion, &ubik_dbVersion, sizeof(struct ubik_version));
+    memcpy(&aparm->syncTid, &ubik_dbTid, sizeof(struct ubik_tid));
     aparm->activeWrite = (ubik_dbase->flags & DBWRITING);
     aparm->tidCounter = ubik_dbase->tidCounter;
     
